import { NsTypography, NsIcon, NsAccordionHeaderProps, AccordionVariant, NsIconProps, AccordionVariantType } from '..';
import { styled } from '@nuskin/foundation-theme';
import { isValidIconName } from '../icon/NsIconVariants';
import { getAccordionColor } from './colorMap';

type StyledType = { variant: AccordionVariantType; invert: boolean };

const StyledHeader = styled('header')<StyledType>(({ theme, variant, invert }) => {
    const { headBg, headText } = getAccordionColor({ theme, variant, invert, keys: ['headBg', 'headText'] });
    let borderBottom = 'none';
    if (variant === AccordionVariant.Compact) {
        borderBottom = '1px solid rgb(0,0,0,0.125)';
    }
    return {
        backgroundColor: headBg,
        color: headText,
        cursor: 'pointer',
        display: 'grid',
        gap: '4px',
        gridTemplateColumns: 'auto 1fr 24px',
        padding: '9px 16px',
        borderBottom,
    } as any;
});

/**
 * NsAccordionHeader is primarily used by NsToggleSection and NsAccordionItem
 * as a header, so it accepts `title` , `isOpen` and `onClick`
 */
const NsAccordionHeader = ({
    title,
    onClick,
    isOpen,
    additionalProps,
    openedIconName,
    closedIconName,
    variant,
    headerTypographyVariant,
    startIcon,
    invert,
    cslp,
}: NsAccordionHeaderProps) => {
    return (
        <StyledHeader
            invert={invert}
            role="button"
            aria-expanded={isOpen ? 'true' : 'false'}
            className={`section-header ${isOpen ? 'expanded' : ''} ${additionalProps?.className ?? ''}`}
            onClick={onClick}
            variant={variant}
        >
            <HeaderIcon {...startIcon} />
            {typeof title === 'string' ? (
                <NsTypography variant={headerTypographyVariant ?? 'h4'} weight="bold" {...(cslp?.header ?? {})}>
                    {title}
                </NsTypography>
            ) : (
                title
            )}
            <span className="header-icon">
                <NsIcon name={isOpen ? openedIconName ?? 'arrowUp' : closedIconName ?? 'arrowDown'} />
            </span>
        </StyledHeader>
    );
};
export default NsAccordionHeader;

const HeaderIcon = (props: Partial<NsIconProps>) => {
    const hasIcon = props?.name ? isValidIconName(props?.name) : false;
    if (!hasIcon) return <span />;
    return <NsIcon {...(props as NsIconProps)} />;
};
