import {Themed} from '../common.types';
import {AccordionVariantType} from './enums';
import {ColorUtils, FoundationTheme} from '@nuskin/foundation-theme';
const {isDarkMode, color} = ColorUtils;
const compKeys = ['contentBg', 'contentText', 'headBg', 'headText'];
type CompKeys = (typeof compKeys)[number];
type VariantColors = Record<
    CompKeys,
    {
        light: [FoundationTheme.AppColors, string];
        dark: [FoundationTheme.AppColors, string];
    }
>;

const colorObject: Record<string, [FoundationTheme.AppColors, string]> = {
    n10: ['primary', 'dark'], // #121212
    n20: ['primary', 'black'], // #252525
    n40: ['neutral', '80'], // #444444
    n45: ['neutral', '70'], // #5f5f5f
    n50: ['neutral', '60'], // #8c8c8c
    n80: ['neutral', '50'], // #b2b2b2
    n85: ['neutral', '40'], // #e0e0e0
    n90: ['neutral', '30'], // #ededed
    n95: ['primary', 'gray'], // #f5f5f5
    n100: ['primary', 'white'], // #fff
};
export const colorMap: Record<AccordionVariantType, VariantColors> = {
    basic: {
        contentBg: {
            light: colorObject.n95,
            dark: colorObject.n20,
        },
        contentText: {
            light: colorObject.n10,
            dark: colorObject.n95,
        },
        headBg: {
            light: colorObject.n100,
            dark: colorObject.n20,
        },
        headText: {
            light: colorObject.n10,
            dark: colorObject.n95,
        },
    },
    compact: {
        contentBg: {
            light: colorObject.n100,
            dark: colorObject.n10,
        },
        contentText: {
            light: colorObject.n10,
            dark: colorObject.n90,
        },
        headBg: {
            light: colorObject.n100,
            dark: colorObject.n10,
        },
        headText: {
            light: colorObject.n10,
            dark: colorObject.n90,
        },
    },
    gray: {
        contentBg: {
            light: colorObject.n85,
            dark: colorObject.n40,
        },
        contentText: {
            light: colorObject.n40,
            dark: colorObject.n85,
        },
        headBg: {
            light: colorObject.n90,
            dark: colorObject.n45,
        },
        headText: {
            light: colorObject.n45,
            dark: colorObject.n90,
        },
    },
    stripe: {
        contentBg: {
            light: colorObject.n90,
            dark: colorObject.n45,
        },
        contentText: {
            light: colorObject.n45,
            dark: colorObject.n90,
        },
        headBg: {
            light: colorObject.n100,
            dark: colorObject.n40,
        },
        headText: {
            light: colorObject.n40,
            dark: colorObject.n100,
        },
    },
};

type GetAccordionColor = {
    variant: AccordionVariantType;
    invert: boolean;
    keys: CompKeys[];
} & Themed;
export const getAccordionColor = ({theme, variant, invert, keys}: GetAccordionColor): Record<CompKeys, string> => {
    const isDark = invert ? !isDarkMode({theme}) : isDarkMode({theme});
    const darkLabel = isDark ? 'dark' : 'light';
    const result: Record<string, string> = {};
    for (const colorKey of keys) {
        const [appColorBg, appSubColorBg] = colorMap[variant][colorKey][darkLabel];
        const colorValue = color(appColorBg, appSubColorBg)({theme});
        result[colorKey] = colorValue;
    }
    return result;
};
