import { render, screen, waitFor } from '@/test-utils/index';
import userEvent from '@testing-library/user-event';
import React from 'react';

import { AutocompleteMockList } from '../autocomplete/mock/MockData';
import { OptionUiComponent } from '../autocomplete/mock/MockUI';
import NsAutocomplete from '../autocomplete/NsAutocomplete';

const commonProps = {
    value: '',
    inputValue: '',
    onInputChange: jest.fn(),
    onChange: jest.fn(),
    options: AutocompleteMockList,
    placeholder: 'autocomplete-input',
    OptionsUI: OptionUiComponent,
    // renderOption: (props: any) => <li {...props}>{props.value}</li>,
};
describe('CustomAutocomplete', () => {
    it('1. should render autocomplete component', () => {
        render(<NsAutocomplete {...commonProps} />);
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        expect(autocompleteInput).toBeInTheDocument();
    });
    it('2. check that onInputChange gets called', async () => {
        const onInputChangeMock = jest.fn();
        render(<NsAutocomplete {...commonProps} onInputChange={onInputChangeMock} />);
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        expect(autocompleteInput).toBeInTheDocument();
        await userEvent.type(autocompleteInput, 'GS Facial');
        expect(onInputChangeMock).toHaveBeenCalled();
    }, 100000);

    it('3. displays options when typing in the input', async () => {
        const onInputChangeMock = jest.fn();
        render(<NsAutocomplete {...commonProps} onInputChange={onInputChangeMock} />);
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        await userEvent.type(autocompleteInput, 'GS Facial');
        await waitFor(
            () => {
                const option1 = screen.getByText('GS Facial Gels 2pk Subscription');
                expect(option1).toBeInTheDocument();
            },
            { timeout: 5000 }
        );
    }, 40000);

    it('4. selects an option when clicking on it', async () => {
        const onChangeMock = jest.fn();
        render(<NsAutocomplete {...commonProps} onChange={onChangeMock} />);
        const autocompleteInput = screen.getByPlaceholderText(commonProps.placeholder);
        await userEvent.type(autocompleteInput, 'GS Facial');
        await waitFor(async () => {
            const optionLi = screen.getByText('GS Facial Spa');
            await userEvent.click(optionLi);
        });
        expect(onChangeMock).toHaveBeenCalled();
    }, 40000);

    it('5. should load more options when clicking load more button', async () => {
        const seeMore = {
            text: 'See More',
            show: true,
            onSeeMore: jest.fn(),
        };
        render(<NsAutocomplete seeMore={seeMore} {...commonProps} />);
        const autocompleteInput = screen.getByPlaceholderText(commonProps.placeholder);
        await userEvent.type(autocompleteInput, 'GS Facial');
        await waitFor(async () => {
            const loadMoreButton = screen.getByText(seeMore.text);
            await userEvent.click(loadMoreButton);
        });
        expect(seeMore.onSeeMore).toHaveBeenCalled();
    }, 40000);

    it('6. should clear options when clicking clear button', async () => {
        const clear = {
            text: 'Clear All',
            show: true,
            onClear: jest.fn(),
        };
        render(<NsAutocomplete clear={clear} {...commonProps} />);
        const autocompleteInput = screen.getByPlaceholderText(commonProps.placeholder);
        await userEvent.type(autocompleteInput, 'GS Facial');
        await waitFor(async () => {
            const clearButton = screen.getByText(clear.text);
            await userEvent.click(clearButton);
        });
    }, 40000);
});
