import { AutocompleteChangeDetails, AutocompleteChangeReason, ComponentsProps } from '@mui/material';
import React, { HTMLAttributes, SyntheticEvent } from 'react';
import { AdditionalProps } from '../common.types';

import { NsIconNameType } from '../icon';

export type NsAutocompleteProps = {
    id?: string;
    options: OptionsProps[];
    loading?: boolean;
    OptionsUI: React.ComponentType<any>;
    noOptionsText?: string;
    /*
        Callback fired when the input value changes.
        event The event source of the callback.
        value The new value of the text input.
        reason Can be: "input" (user input), "reset" (programmatic change), "clear".
     */
    onInputChange(event: SyntheticEvent, value: string, reason: string): void;
    /*
        event The event source of the callback.
        value The new value of the component.
        reason One of "createOption", "selectOption", "removeOption", "blur" or "clear".
     */
    onChange(
        event: SyntheticEvent<Element, Event>,
        value: string | OptionsProps | null,
        reason: AutocompleteChangeReason,
        details?: AutocompleteChangeDetails<OptionsProps> | undefined
    ): void;
    clear?: {
        text?: string;
        show?: boolean; //default to false
        onClear: () => void;
        recentSearchText?: string;
    };
    seeMore?: {
        text?: string;
        show?: boolean; //default to false
        onSeeMore: () => void;
    };
    placeholder?: string;
    className?: string;
    iconStart?: string | React.ReactNode;
    iconEnd?: string | React.ReactNode;
    inputValue: string;
    value: string | OptionsProps | null;
    isFilterEnabled?: boolean;
} & AdditionalProps;

export type ListUiProps = {
    option: OptionsProps;
};

export type OptionsProps = {
    id: string;
    group?: string;
    value: string;
    icon?: NsIconNameType;
    image?: string;
    groupBgColor?: string;
};

export type ComponentBoxProps = ComponentsProps & HTMLAttributes<HTMLElement>;
