import { Button as MUIButton } from '@mui/material';

import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
import { ButtonConfig } from '@nuskin/foundation-theme/src/common/themes/types/button';

import { NsButtonProps } from './types.d';
import { generateContainedStyle, generateIconOnlyStyles, generateOutlinedStyle, generateTextStyles } from './helper';

const { buttonColor, paletteColor } = ColorUtils;

const getButtonConfig = (theme: FoundationTheme.Theme, attribute: keyof ButtonConfig) => {
    const { config } = theme || {};
    return config?.components?.button?.[attribute] || '';
};

export const StyledButton = styled(MUIButton)<NsButtonProps>(
    ({ theme, color, size, darkModeEnabled, variant, iconOnly }) => {
        const borderRadius = getButtonConfig(theme, 'borderRadius') || 0;
        const focusBorderColor = getButtonConfig(theme, 'focusColor');
        // TODO: remove as any from the theme and color
        const sizeStyle = (theme as any)?.components?.button?.['size']?.[size ?? '']?.padding ?? {};
        const btnColor = color as any;

        let buttonStyles = {};
        const hovered = buttonColor(btnColor, 'hovered')({ theme });
        const pressed = buttonColor(btnColor, 'pressed')({ theme });
        const focused = buttonColor(btnColor, 'focused')({ theme });
        const textColor = paletteColor(btnColor, 'contrastText')({ theme, darkModeEnabled });
        const backgroundColor = paletteColor(btnColor)({ theme, darkModeEnabled });

        if (variant === 'contained') {
            buttonStyles = generateContainedStyle({ backgroundColor, textColor, hovered, pressed, focused });
        } else if (variant === 'outlined') {
            const activeColor = paletteColor(btnColor)({ theme });
            buttonStyles = generateOutlinedStyle({ borderColor: backgroundColor, hovered, pressed, activeColor });
        } else if (variant === 'text') {
            buttonStyles = generateTextStyles({ underlineColor: backgroundColor, hovered, pressed });
        } else if (iconOnly) {
            buttonStyles = generateIconOnlyStyles();
        }

        return {
            gap: '10px',
            borderRadius,
            '&:focus': {
                border: `1px solid ${focusBorderColor} !important`,
            },
            '&:disabled': {
                backgroundColor: buttonColor(btnColor, 'disabled'),
                color: buttonColor(btnColor, 'disabledText'),
            },
            ...buttonStyles,
            ...sizeStyle,
        };
    }
);
