import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsImage } from '../';

type NsAwardCardProps = {
    title: string;
    awardName: string;
    mediaOutlet: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        alignItems: 'center',
        width: '160px',
        height: 'auto',
        '.image': {
            width: '160px',
            height: 'auto',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            flexDirection: 'column',
            textAlign: 'center',
            alignItems: 'center',
        },
        '.title': {
            fontSize: '16px',
            fontWeight: 'bold',
            marginTop: '30px',
        },
        '.awardName': {
            fontSize: '16px',
            fontWeight: '400',
            marginTop: '20px',
        },
        '.mediaOutlet': {
            fontSize: '11px',
            fontWeight: '400',
            marginTop: '20px',
        },
        '.action-link': {
            marginTop: '10px',
            fontSize: '14px',
            alignSelf: 'start',
        },
    };
});

export default function NsAwardCard({
    title,
    awardName,
    mediaOutlet,
    backgroundImageUrl,
    backgroundImageAlt,
    className,
}: NsAwardCardProps) {
    return (
        <CardContainer className={className} role="award-card" component="div" data-testid="award-card">
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <article className="title">{title}</article>
                <article className="awardName">{awardName}</article>
                <article className="mediaOutlet">{mediaOutlet}</article>
            </div>
        </CardContainer>
    );
}
