import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsTypography } from '../';
import NsBrandWrapper from './NsBrandWrapper';
import NsBrandLogo from './NsBrandLogo';
import NsBgCard from './NsBgCard';
import cardSizes from './cardSizes';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsBrandCardProps = {
    title?: string;
    brandImageUrl: string;
    backgroundImageUrl: string;
    size?: 'small' | 'large';
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled((props: any) => <Box {...props} />)(({ size }) => {
    const { small, large } = cardSizes;
    let width, height;

    if (size === 'small') {
        width = small.width;
        height = small.height;
    } else {
        width = large.width;
        height = large.height;
    }

    return {
        width,
        display: 'flex',
        alignItems: 'start',
        justifyContent: 'center',
        position: 'relative',
        flexDirection: 'column',
        '.brand-title': {
            marginTop: '15px',
            fontSize: '20px',
            display: 'inline-block',
            wordBreak: 'break-word',
        },
        ':hover': {
            '.brand-title': {
                opacity: '0.7',
            },
        },
        '.cta': {
            marginTop: '15px',
            width: '100%',
        },
        '.image': {
            width,
            height,
            backgroundSize: 'cover',
            backgroundPosition: 'center',
        },
    };
});
export default function NsBrandCard({
    title,
    brandImageUrl,
    backgroundImageUrl,
    button,
    size,
    className,
}: NsBrandCardProps) {
    return (
        <CardContainer className={className} role="brand-card" component="div" data-testid="brand-card" size={size}>
            <NsBgCard backgroundImageUrl={backgroundImageUrl} className="image">
                <NsBrandWrapper>
                    <NsBrandLogo component="img" image={brandImageUrl} />
                </NsBrandWrapper>
            </NsBgCard>
            {title ? (
                <NsTypography variant="h3" className="brand-title">
                    {title}
                </NsTypography>
            ) : null}
            {button ? <CardButton {...button} /> : null}
        </CardContainer>
    );
}
