import { NsImage } from '../';
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsHeroCardLevel2Props = {
    brandName: string;
    cardTitle: string;
    cardDescription: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        backgroundClip: 'border-box',
        display: 'flex',
        flexDirection: 'row' as 'row',
        wordWrap: 'break-word' as 'break-word',
        position: 'relative',
        overflow: 'hidden',
        height: '250px',
        width: '100%',
        '.content': {
            height: '100%',
            padding: '50px',
            display: 'flex',
            flexDirection: 'column' as 'column',
            position: 'absolute',
            top: 0,
            left: 0,
            boxSizing: 'border-box',
        },
        '.bg-image': {
            objectFit: 'cover',
        },
        '.brand-container': {
            backgroundColor: '#fff',
            width: 'fit-content',
            paddingLeft: '10px',
            paddingRight: '10px',
        },
        '.body-title': {
            fontSize: '26px',
            lineHeight: '44px',
            marginBottom: '5px',
        },
        '.body-text': {
            fontSize: '12px',
            fontWeight: 700,
            marginBottom: '5px',
        },
        '@media (max-width:768px)': {
            '.content': {
                padding: '5%',
            },
        },
    };
});

const NsHeroCardLevel2 = ({
    brandName,
    cardTitle,
    cardDescription,
    backgroundImageUrl,
    backgroundImageAlt,
    button,
    className,
}: NsHeroCardLevel2Props) => {
    return (
        <CardContainer className={className} data-testid="hero-card-level-2">
            <NsImage variant="fill" alt={backgroundImageAlt} src={backgroundImageUrl} className="bg-image" />
            <div className="content">
                <div className="brand-container">
                    <article>{brandName}</article>
                </div>
                <article className="body-title">{cardTitle}</article>
                <article className="body-text">{cardDescription}</article>
                <div>{button ? <CardButton {...button} /> : null}</div>
            </div>
        </CardContainer>
    );
};
export default NsHeroCardLevel2;
