import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { NsImage, NsTypography } from '../';
import CardButton from './CardButton';
import { NsCardButton } from './types';

type NsMediumCardProps = {
    title: string;
    titleFontWeight?: 'bold' | 'normal' | 'light';
    subtitle: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    button?: NsCardButton;
    className?: string;
};

const CardContainer = styled(Box)(() => {
    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        '.image': {
            width: '300px',
            height: '300px',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            width: '300px',
            flexDirection: 'column',
        },
        '.subtitle': {
            fontSize: '16px',
            fontWeight: '400',
            marginTop: '10px',
        },
        '.title': {
            fontSize: '20px',
            marginTop: '10px',
        },
        '.cta': {
            marginTop: '10px',
        },
    };
});

export default function NsMediumCard({
    title,
    titleFontWeight,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    button,
    className,
}: NsMediumCardProps) {
    return (
        <CardContainer className={className} role="medium-card" component="div" data-testid="medium-card">
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <NsTypography variant="h5" color="primary" className="title" weight={titleFontWeight}>
                    {title}
                </NsTypography>
                <article className="subtitle">{subtitle}</article>
                {button ? <CardButton {...button} /> : null}
            </div>
        </CardContainer>
    );
}
