import React, { useState } from 'react';
import { NsEmailSimpleProps } from './types';
import { NsInputField } from '../input';
import { fieldStateType } from '../input/types';
import { emailPattern } from '../validations/regex';

const NsEmailSimple = (props: NsEmailSimpleProps) => {
    const {
        disabled,
        label,
        required,
        maxLength,
        invalidEmailMessage,
        dupedEmailMessage,
        requiredErrorMessage,
        checkEmail,
        additionalProps,
    } = props;
    const [fieldState, setFieldState] = useState<fieldStateType>();
    const [errorMsg, setErrorMessage] = useState('');

    const handleBlur = async (e: React.FocusEvent<HTMLInputElement>) => {
        const emailInput = e.target.value.toLowerCase().trim();
        let fieldStateValue: fieldStateType;
        let errorMessageValue = '';
        if (required && !emailInput) {
            fieldStateValue = 'error';
            errorMessageValue = requiredErrorMessage;
        } else if (!emailPattern.test(emailInput)) {
            fieldStateValue = 'error';
            errorMessageValue = invalidEmailMessage;
        } else if (typeof checkEmail === 'function') {
            try {
                const [isValid, isAvailable] = await checkEmail();
                if (!isValid) {
                    fieldStateValue = 'error';
                    errorMessageValue = invalidEmailMessage;
                } else if (!isAvailable) {
                    fieldStateValue = 'error';
                    errorMessageValue = dupedEmailMessage;
                } else {
                    fieldStateValue = undefined;
                    errorMessageValue = '';
                }
            } catch (error) {
                console.error('API error', error);
            }
        } else {
            //TODO What happens when user does not pass valid checkEmail function
        }
        setFieldState(fieldStateValue);
        setErrorMessage(errorMessageValue);
    };
    return (
        <NsInputField
            required={required}
            disabled={disabled}
            label={label}
            onBlur={handleBlur}
            inputProps={{ maxLength }}
            additionalProps={{ testid: additionalProps?.testid ?? 'email-field-test' }}
            helperText={errorMsg}
            fieldState={fieldState}
            InputProps={{
                endAdornment: null,
            }}
        />
    );
};

export default NsEmailSimple;
