/**
 * NsTextStrip.tsx
 * @description NsTextStrip component for scrolling text CTA
 */

import React from 'react';

import { NsTextStripProps } from './types.d';
import { NsTypography } from '../typography';
import { NsLink } from '../link';
import { styled, ColorUtils } from '@nuskin/foundation-theme';

const { isDarkMode, paletteColor, color } = ColorUtils;

const StyledHeader = styled.header`
    background: ${(props) => (
        !isDarkMode(props)
            ? color('primary', 'gray')
            : paletteColor('primary', 'contrastText')
    )};
    display: flex;
    flex-direction: column;
    min-height: 60px;
    padding: 2px 10px 12px;
    a {
        text-decoration: underline;
        font-weight: 600;
    }
`;

const NsTextStrip = (props: NsTextStripProps) => {
    const { alignment = 'center', text, description, link, className = '' } = props;

    return (
        <StyledHeader className={`${className} items-${alignment}`}>
            <NsTypography variant="h5" weight="bold">
                {text}
            </NsTypography>
            <NsTypography variant="body-xs">
                {description}&nbsp;
                {link?.href ? <NsLink href={link.href}>{link.title}</NsLink> : ''}
            </NsTypography>
        </StyledHeader>
    );
};

export default NsTextStrip;
